@@ -50,6 +50,8 @@ BasicSettings::BasicSettings(LXQt::Settings* settings, QWidget *parent) :
     connect(bottomCenterRB, &QRadioButton::clicked, this, &BasicSettings::updateNotification);
     connect(bottomRightRB,  &QRadioButton::clicked, this, &BasicSettings::updateNotification);
 
+    connect(previewButton, &QAbstractButton::clicked, this, &BasicSettings::previewNotification);
+
     LXQt::Notification *serverTest = new LXQt::Notification(QString(), this);
     serverTest->queryServerInfo();
 
@@ -126,7 +128,29 @@ void BasicSettings::updateNotification()
         align = QL1S("bottom-right");
 
     mSettings->setValue(QL1S("placement"), align);
-    LXQt::Notification::notify(tr("Notification demo ") + align,
+}
+
+void BasicSettings::previewNotification()
+{
+   QString str;
+    if (topLeftRB->isChecked())
+        str = tr("at top left");
+    else if (topCenterRB->isChecked())
+        str = tr("at top center");
+    else if (topRightRB->isChecked())
+        str = tr("at top right");
+    else if (centerLeftRB->isChecked())
+        str = tr("at center left");
+    else if (centerRightRB->isChecked())
+        str = tr("at center right");
+    else if (bottomLeftRB->isChecked())
+        str = tr("at bottom left");
+    else if (bottomCenterRB->isChecked())
+        str = tr("at bottom center");
+    else // if (bottomRightRB->isChecked())
+        str = tr("at bottom right");
+
+    LXQt::Notification::notify(tr("Notification demo ") + str,
                                tr("This is a test notification.\n All notifications will now appear here on LXQt."),
                                QStringLiteral("lxqt"));
 }
