@@ -6,7 +6,7 @@
     <message>
         <location filename="../advancedsettings.ui" line="67"/>
         <source>Sizes</source>
-        <translation>Velikosti</translation>
+        <translation>Rozměry</translation>
     </message>
     <message>
         <location filename="../advancedsettings.ui" line="75"/>
@@ -22,12 +22,12 @@
     <message>
         <location filename="../advancedsettings.ui" line="99"/>
         <source>Spacing:</source>
-        <translation>Rozestup:</translation>
+        <translation>Rozestupy:</translation>
     </message>
     <message>
         <location filename="../advancedsettings.ui" line="118"/>
         <source>Duration</source>
-        <translation>Doba trvání</translation>
+        <translation>Doba trvání zobrazení</translation>
     </message>
     <message>
         <location filename="../advancedsettings.ui" line="130"/>
@@ -52,12 +52,22 @@
     <message>
         <location filename="../advancedsettings.ui" line="183"/>
         <source>When unchecked the notification will always show on primary screen</source>
-        <translation>Pokud není zaškrtnuto, oznámení se vždy zobrazí na hlavní obrazovce</translation>
+        <translation>Pokud není zaškrtnuto, oznámení se zobrazí vždy na hlavní obrazovce</translation>
     </message>
     <message>
         <location filename="../advancedsettings.ui" line="186"/>
         <source>Show notifications on screen with the mouse</source>
-        <translation>Ukázat oznámení na obrazovce pomocí myši</translation>
+        <translation>Ukázat oznámení na té obrazovce, na které se nachází ukazatel myši</translation>
+    </message>
+    <message>
+        <location filename="../advancedsettings.ui" line="196"/>
+        <source>Do Not Disturb</source>
+        <translation>Nerušení pozornosti</translation>
+    </message>
+    <message>
+        <location filename="../advancedsettings.ui" line="202"/>
+        <source>Only save notifications</source>
+        <translation>Upozornění nevyskakovat, jen ukládat</translation>
     </message>
     <message>
         <location filename="../advancedsettings.ui" line="17"/>
@@ -89,47 +99,87 @@
 <context>
     <name>BasicSettings</name>
     <message>
-        <location filename="../basicsettings.ui" line="23"/>
-        <source>Basic Settings</source>
-        <translation>Základní nastavení</translation>
-    </message>
-    <message>
-        <location filename="../basicsettings.ui" line="30"/>
+        <location filename="../basicsettings.ui" line="17"/>
         <source>Position on screen</source>
         <translation>Pozice na obrazovce</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="61"/>
-        <source>&lt;b&gt;Warning:&lt;/b&gt; notifications daemon is slow to respond.
-Keep trying to connect…</source>
-        <translation>&lt;b&gt;Varování:&lt;/b&gt; démon upozornění odpovídá pomalu.
-Pokračujte v pokusech o připojení se …</translation>
+        <location filename="../basicsettings.ui" line="176"/>
+        <source>Preview</source>
+        <translation>Náhled</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="70"/>
+        <location filename="../basicsettings.cpp" line="63"/>
+        <source>&lt;b&gt;Warning:&lt;/b&gt; notifications daemon is slow to respond.
+Keep trying to connect…</source>
+        <translation>&lt;b&gt;Varování:&lt;/b&gt; Proces služby oznamování odpovídá pomalu.
+Pokračuje se v pokusech o připojení se…</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.cpp" line="72"/>
         <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
 A fallback will be used.</source>
-        <translation>&lt;b&gt;Varování:&lt;/b&gt; Není spuštěná žádná služba oznamování.
+        <translation>&lt;b&gt;Varování:&lt;/b&gt; Není spuštěný žádný proces služby oznamování.
 Použije se náhrada.</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="73"/>
+        <location filename="../basicsettings.cpp" line="75"/>
         <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
 These settings won&apos;t have any effect on it!</source>
-        <translation>&lt;b&gt;Varování:&lt;/b&gt; Je spuštěná další služba oznamování (od třetí strany) (%1).
+        <translation>&lt;b&gt;Varování:&lt;/b&gt; Je spuštěná jiná služba oznamování (od třetí strany) (%1).
 Tato nastavení na ni nemají žádný vliv!</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="131"/>
+        <location filename="../basicsettings.cpp" line="137"/>
+        <source>at top left</source>
+        <translation>vlevo nahoře</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.cpp" line="139"/>
+        <source>at top center</source>
+        <translation>nahoře uprostřed</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.cpp" line="141"/>
+        <source>at top right</source>
+        <translation>vpravo nahoře</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.cpp" line="143"/>
+        <source>at center left</source>
+        <translation>vlevo uprostřed</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.cpp" line="145"/>
+        <source>at center right</source>
+        <translation>vpravo uprostřed</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.cpp" line="147"/>
+        <source>at bottom left</source>
+        <translation>vlevo dole</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.cpp" line="149"/>
+        <source>at bottom center</source>
+        <translation>dole uprostřed</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.cpp" line="151"/>
+        <source>at bottom right</source>
+        <translation>vpravo dole</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.cpp" line="153"/>
         <source>Notification demo </source>
         <translation>Zkušební oznámení </translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="132"/>
+        <location filename="../basicsettings.cpp" line="154"/>
         <source>This is a test notification.
  All notifications will now appear here on LXQt.</source>
         <translation>Toto je zkušební oznámení.
-Všechna oznámení se nyní budou objevovat zde na LXQt.</translation>
+Všechna oznámení, procházející přes LXQt, se nyní budou objevovat zde.</translation>
     </message>
 </context>
 <context>
@@ -141,13 +191,13 @@ Všechna oznámení se nyní budou objevovat zde na LXQt.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="44"/>
-        <source>Basic Settings</source>
-        <translation>Základní nastavení</translation>
+        <source>General Settings</source>
+        <translation>Obecná nastavení</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="48"/>
-        <source>Advanced Settings</source>
-        <translation>Pokročilá nastavení</translation>
+        <source>Position</source>
+        <translation>Pozice</translation>
     </message>
 </context>
 </TS>
