@@ -11,7 +11,7 @@
     <message>
         <location filename="../advancedsettings.ui" line="99"/>
         <source>Spacing:</source>
-        <translation>Razmaci:</translation>
+        <translation>Razmak:</translation>
     </message>
     <message>
         <location filename="../advancedsettings.ui" line="118"/>
@@ -41,13 +41,13 @@
     <message>
         <location filename="../advancedsettings.ui" line="25"/>
         <source>How many to save:</source>
-        <translation>Broj spremljenih obavijesti:</translation>
+        <translation>Koliko obavijesti čuvati:</translation>
     </message>
     <message>
         <location filename="../advancedsettings.ui" line="39"/>
         <location filename="../advancedsettings.ui" line="49"/>
         <source>Application name is on the top of notification.</source>
-        <translation>Ime programa se nalazi pri vrhu obavijesti.</translation>
+        <translation>Ime programa se nalazi na početku obavijesti.</translation>
     </message>
     <message>
         <location filename="../advancedsettings.ui" line="42"/>
@@ -85,47 +85,97 @@
         <source>Show notifications on screen with the mouse</source>
         <translation>Prikaži obavijesti na ekranu s mišem</translation>
     </message>
+    <message>
+        <location filename="../advancedsettings.ui" line="196"/>
+        <source>Do Not Disturb</source>
+        <translation>Ne smetaj</translation>
+    </message>
+    <message>
+        <location filename="../advancedsettings.ui" line="202"/>
+        <source>Only save notifications</source>
+        <translation>Spremi samo obavijesti</translation>
+    </message>
 </context>
 <context>
     <name>BasicSettings</name>
     <message>
-        <location filename="../basicsettings.ui" line="23"/>
-        <source>Basic Settings</source>
-        <translation>Osnovne postavke</translation>
-    </message>
-    <message>
-        <location filename="../basicsettings.ui" line="30"/>
+        <location filename="../basicsettings.ui" line="17"/>
         <source>Position on screen</source>
         <translation>Položaj na ekranu</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="61"/>
+        <location filename="../basicsettings.ui" line="176"/>
+        <source>Preview</source>
+        <translation>Pregled</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.cpp" line="63"/>
         <source>&lt;b&gt;Warning:&lt;/b&gt; notifications daemon is slow to respond.
 Keep trying to connect…</source>
         <translation>&lt;b&gt;Oprez:&lt;/b&gt; demon obavijesti reagira sporo.
 Nastavi se povezivati …</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="70"/>
+        <location filename="../basicsettings.cpp" line="72"/>
         <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
 A fallback will be used.</source>
         <translation>&lt;b&gt;Upozorenje:&lt;/b&gt; Nijedan demon za obavijesti nije pokrenut.
 Koristit će se rezervni.</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="73"/>
+        <location filename="../basicsettings.cpp" line="75"/>
         <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
 These settings won&apos;t have any effect on it!</source>
         <translation>&lt;b&gt;Upozorenje:&lt;/b&gt; Pokrenut je jedan strani demon za obavijesti (%1).
 Ove postavke na njega ne utječu!</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="131"/>
-        <source>Notification demo </source>
-        <translation>Demonstracija obavijesti </translation>
+        <location filename="../basicsettings.cpp" line="137"/>
+        <source>at top left</source>
+        <translation>gore lijevo</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="132"/>
+        <location filename="../basicsettings.cpp" line="139"/>
+        <source>at top center</source>
+        <translation>gore centrirano</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.cpp" line="141"/>
+        <source>at top right</source>
+        <translation>gore desno</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.cpp" line="143"/>
+        <source>at center left</source>
+        <translation>centrirano lijevo</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.cpp" line="145"/>
+        <source>at center right</source>
+        <translation>centrirano desno</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.cpp" line="147"/>
+        <source>at bottom left</source>
+        <translation>dolje lijevo</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.cpp" line="149"/>
+        <source>at bottom center</source>
+        <translation>dolje centrirano</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.cpp" line="151"/>
+        <source>at bottom right</source>
+        <translation>dolje desno</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.cpp" line="153"/>
+        <source>Notification demo </source>
+        <translation>Prikaz obavijesti </translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.cpp" line="154"/>
         <source>This is a test notification.
  All notifications will now appear here on LXQt.</source>
         <translation>Ovo je testna obavijest.
@@ -137,17 +187,17 @@ Sve obavijesti će se sada ovdje pojaviti na LXQt-u.</translation>
     <message>
         <location filename="../mainwindow.cpp" line="41"/>
         <source>Desktop Notifications</source>
-        <translation>Obavijesti radne površine</translation>
+        <translation>Obavijesti na radnoj površini</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="44"/>
-        <source>Basic Settings</source>
-        <translation>Osnovne postavke</translation>
+        <source>General Settings</source>
+        <translation>Opće postavke</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="48"/>
-        <source>Advanced Settings</source>
-        <translation>Napredne postavke</translation>
+        <source>Position</source>
+        <translation>Pozicija</translation>
     </message>
 </context>
 </TS>
