@@ -47,17 +47,27 @@
     <message>
         <location filename="../advancedsettings.ui" line="177"/>
         <source>Screen</source>
-        <translation type="unfinished"></translation>
+        <translation>Obrazovka</translation>
     </message>
     <message>
         <location filename="../advancedsettings.ui" line="183"/>
         <source>When unchecked the notification will always show on primary screen</source>
-        <translation type="unfinished"></translation>
+        <translation>Ak políčko nie je zaškrtnuté, oznámenie sa vždy zobrazí na hlavnej obrazovke</translation>
     </message>
     <message>
         <location filename="../advancedsettings.ui" line="186"/>
         <source>Show notifications on screen with the mouse</source>
-        <translation type="unfinished"></translation>
+        <translation>Ukázať oznámenia na obrazovke pomocou myši</translation>
+    </message>
+    <message>
+        <location filename="../advancedsettings.ui" line="196"/>
+        <source>Do Not Disturb</source>
+        <translation>Nerušiť</translation>
+    </message>
+    <message>
+        <location filename="../advancedsettings.ui" line="202"/>
+        <source>Only save notifications</source>
+        <translation>Nezobrazovať notifikácie</translation>
     </message>
     <message>
         <location filename="../advancedsettings.ui" line="17"/>
@@ -89,42 +99,83 @@
 <context>
     <name>BasicSettings</name>
     <message>
-        <location filename="../basicsettings.ui" line="23"/>
-        <source>Basic Settings</source>
-        <translation>Základné nastavenia</translation>
-    </message>
-    <message>
-        <location filename="../basicsettings.ui" line="30"/>
+        <location filename="../basicsettings.ui" line="17"/>
         <source>Position on screen</source>
         <translation>Pozície na obrazovke</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="61"/>
-        <source>&lt;b&gt;Warning:&lt;/b&gt; notifications daemon is slow to respond.
-Keep trying to connect…</source>
-        <translation type="unfinished"></translation>
+        <location filename="../basicsettings.ui" line="176"/>
+        <source>Preview</source>
+        <translation>Náhľad</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="70"/>
+        <location filename="../basicsettings.cpp" line="63"/>
+        <source>&lt;b&gt;Warning:&lt;/b&gt; notifications daemon is slow to respond.
+Keep trying to connect…</source>
+        <translation>&lt;b&gt;Upozornenie:&lt;/b&gt; démon upozornení odpovedá pomaly.
+Pokračujte v pokusoch o pripojenie…</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.cpp" line="72"/>
         <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
 A fallback will be used.</source>
         <translation>&lt;b&gt;Varovanie:&lt;/b&gt; Není spustená žiadna služba oznamovania.
 Použije se náhrada.</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="73"/>
+        <location filename="../basicsettings.cpp" line="75"/>
         <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
 These settings won&apos;t have any effect on it!</source>
         <translation>&lt;b&gt;Varovanie:&lt;/b&gt; Je spustená ďalšia služba oznamovania (od tretej strany) (%1).
 Toto nastavenie na ňu nemá žiaden vplyv!</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="131"/>
+        <location filename="../basicsettings.cpp" line="137"/>
+        <source>at top left</source>
+        <translation>Vľavo hore</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.cpp" line="139"/>
+        <source>at top center</source>
+        <translation>V strede hore</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.cpp" line="141"/>
+        <source>at top right</source>
+        <translation>Vpravo hore</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.cpp" line="143"/>
+        <source>at center left</source>
+        <translation>Vľavo v strede</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.cpp" line="145"/>
+        <source>at center right</source>
+        <translation>V strede vpravo</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.cpp" line="147"/>
+        <source>at bottom left</source>
+        <translation>Vľavo dole</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.cpp" line="149"/>
+        <source>at bottom center</source>
+        <translation>V strede dole</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.cpp" line="151"/>
+        <source>at bottom right</source>
+        <translation>Vpravo dole</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.cpp" line="153"/>
         <source>Notification demo </source>
         <translation>Skúšobné oznámenie </translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="132"/>
+        <location filename="../basicsettings.cpp" line="154"/>
         <source>This is a test notification.
  All notifications will now appear here on LXQt.</source>
         <translation>Toto je skúšobné oznámenie.
@@ -140,13 +191,13 @@ Všetky oznámenia sa teraz budú objavovať tu na LXQt.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="44"/>
-        <source>Basic Settings</source>
-        <translation>Základné nastavenia</translation>
+        <source>General Settings</source>
+        <translation>Všeobecné nastavenia</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="48"/>
-        <source>Advanced Settings</source>
-        <translation>Pokročilé nastavenia</translation>
+        <source>Position</source>
+        <translation>Pozícia</translation>
     </message>
 </context>
 </TS>
